net Package
===========

:mod:`calendarevents` Module
----------------------------

.. automodule:: stoqlib.net.calendarevents
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`socketutils` Module
-------------------------

.. automodule:: stoqlib.net.socketutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`server` Module
--------------------

.. automodule:: stoqlib.net.server
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`webserver` Module
-----------------------

.. automodule:: stoqlib.net.webserver
    :members:
    :undoc-members:
    :show-inheritance:
